@@ -355,7 +355,7 @@ impl<'a> Printer<'a> {
       for (condition, save_point) in conditions_for_info.values() {
         let condition_id = condition.get_unique_id();
 
-        if let Some(resolved_condition_value) = self.resolved_conditions.get(&condition_id).map(|x| x.to_owned()).flatten() {
+        if let Some(resolved_condition_value) = self.resolved_conditions.get(&condition_id).and_then(|x| x.to_owned()) {
           self.resolving_save_point.replace(save_point);
           let mut context = ConditionResolverContext::new(self, save_point.writer_state.get_writer_info(self.writer.get_indent_width()));
           let condition_value = condition.resolve(&mut context);
