@@ -1,6 +1,5 @@
-mod counter_cell;
-pub mod string_utils;
 mod thread_local_bump_allocator;
 
-pub(crate) use counter_cell::*;
+pub mod string_utils;
+
 pub(crate) use thread_local_bump_allocator::*;
